@@ -33,9 +33,9 @@ unsigned int updateTimeStamp(unsigned int before);
 void   setMaxMemoryAllocation(size_t value);
 void   setMinMemoryAllocation(size_t value);
 void   setProbeMemoryAllocation(size_t value);
-size_t getMaxMemoryAllocation();
-size_t getMinMemoryAllocation();
-size_t getProbeMemoryAllocation();
+size_t getMaxMemoryAllocation(void);
+size_t getMinMemoryAllocation(void);
+size_t getProbeMemoryAllocation(void);
 void   increaseMemoryAllocation(size_t amount);
 void   increaseProbeMemoryAllocation(size_t amount);
 void   decreaseMemoryAllocation(size_t amount);
